@@ -17,11 +17,21 @@
         <source>Restore window geometry</source>
         <translation>Obnovit rozměry okna</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation>Vždy použít živý náhled</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
         <translation>Otevírat externí odkazy v okně ReTextu</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Zapnout synchronizovaný posun pro Markdown</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Editor</source>
@@ -49,8 +59,8 @@
     </message>
     <message>
         <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation>Zobrazovat pravý okraj sloupce</translation>
+        <source>Draw vertical line at column</source>
+        <translation>Svislá čára u sloupců</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
@@ -65,22 +75,17 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
+        <translation>Soubor stylu</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Markdown syntax extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
+        <translation>Přípony syntaxe Markdown (oddělené čárkami)</translation>
     </message>
     <message>
-        <location filename="config.py" line="102"/>
+        <location filename="config.py" line="103"/>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
@@ -88,12 +93,12 @@
     <message>
         <location filename="config.py" line="34"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>(prázdý)</translation>
     </message>
     <message>
         <location filename="config.py" line="41"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Otevřít soubor</translation>
     </message>
 </context>
 <context>
@@ -104,7 +109,7 @@
         <translation>Zadejte název lokalizace (např.: cs_CZ)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Nastavit jako výchozí</translation>
     </message>
@@ -114,23 +119,36 @@
     <message>
         <location filename="fakevimeditor.py" line="64"/>
         <source>No write since last change (add ! to override)</source>
-        <translation type="unfinished"></translation>
+        <translation>Žádný zápis od poslední změny (přidejte ! pro přepsání)</translation>
     </message>
     <message>
         <location filename="fakevimeditor.py" line="121"/>
         <source>Information</source>
-        <translation type="unfinished"></translation>
+        <translation>Informace</translation>
+    </message>
+</context>
+<context>
+    <name>ReTextEdit</name>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation>Uložit obrázek</translation>
+    </message>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation>Obrázky (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="115"/>
+        <location filename="tab.py" line="177"/>
         <source>New document</source>
         <translation>Nový dokument</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Nelze analyzovat obsah souboru, zkontrolujte, zda máte nainstalován &lt;a href=&quot;%s&quot;&gt;nezbytný modul&lt;/a&gt;!</translation>
     </message>
@@ -138,419 +156,437 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
-        <translation>Nástrojová lišta Soubor</translation>
+        <translation>Lišta souboru</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
-        <translation>Nástrojová lišta Úpravy</translation>
+        <translation>Lišta úprav</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
-        <translation>Nástrojová lišta Najít</translation>
+        <translation>Lišta hledání</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>Nový</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>Otevřít</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
-        <source>Save</source>
-        <translation>Uložit</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="95"/>
         <source>Set encoding</source>
         <translation>Nastavit kódování</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="1044"/>
+        <source>Reload</source>
+        <translation>Znovu načíst</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
+        <source>Save</source>
+        <translation>Uložit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Uložit jako</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="107"/>
+        <source>Next tab</source>
+        <translation>Následující záložka</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Previous tab</source>
+        <translation>Předchozí záložka</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Tisknout</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>Náhled tisku</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>Zobrazit HTML kód</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation>Změnit font editoru</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation>Změnit font náhledu</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Najít text</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Náhled</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
-        <translation>Průběžný náhled</translation>
+        <translation>Živý náhled</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="144"/>
+        <source>FakeVim mode</source>
+        <translation>Mód FakeVim</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
         <source>Fullscreen mode</source>
-        <translation>Celoobrazovkový režim</translation>
+        <translation>Režim na celou obrazovku</translation>
     </message>
     <message>
-        <location filename="window.py" line="503"/>
+        <location filename="window.py" line="553"/>
         <source>Preferences</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>Ukončit</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
         <translation>Zpět</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>Znovu</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>Kopírovat</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>Vyjmout</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>Vložit</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>Povolit</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>Nastavit lokalizaci</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
-        <translation>Použít k vykreslování WebKit</translation>
+        <translation>Použít WebKit k vykreslování</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
-        <source>Next</source>
-        <translation>Následující</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="174"/>
-        <source>Previous</source>
-        <translation>Předchozí</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Get help online</source>
-        <translation>Získejte nápovědu online</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>About ReText</source>
-        <translation>O ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>About Qt</source>
-        <translation>O Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="200"/>
-        <source>Bold</source>
-        <translation>Tučné</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="202"/>
-        <source>Italic</source>
-        <translation>Kurzíva</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="204"/>
-        <source>Underline</source>
-        <translation>Podtržené</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>Značky</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
-        <source>Symbols</source>
-        <translation>Entity</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="223"/>
-        <source>File</source>
-        <translation>Soubor</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="224"/>
-        <source>Edit</source>
-        <translation>Upravit</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Help</source>
-        <translation>Nápověda</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="228"/>
-        <source>Open recent</source>
-        <translation>Otevřít nedávné</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="241"/>
-        <source>Export</source>
-        <translation>Exportovat</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="262"/>
-        <source>Spell check</source>
-        <translation>Kontrola pravopisu</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="270"/>
-        <source>Default markup</source>
-        <translation>Výchozí syntax</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="273"/>
-        <source>Formatting</source>
-        <translation>Formátování</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="313"/>
-        <source>Search</source>
-        <translation>Najít</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="315"/>
-        <source>Case sensitively</source>
-        <translation>Rozlišovat velikost písmen</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="442"/>
-        <source>New document</source>
-        <translation>Nový dokument</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="591"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Soubor, prosím, někam uložte.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>Zobrazit složku</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="188"/>
+        <source>Next</source>
+        <translation>Následující</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="190"/>
+        <source>Previous</source>
+        <translation>Předchozí</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation>Zavřít</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="195"/>
+        <source>Get help online</source>
+        <translation>Získejte nápovědu online</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="196"/>
+        <source>About ReText</source>
+        <translation>O programu ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="199"/>
+        <source>About Qt</source>
+        <translation>O Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="214"/>
+        <source>Bold</source>
+        <translation>Tučné</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Italic</source>
+        <translation>Kurzíva</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="218"/>
+        <source>Underline</source>
+        <translation>Podtržené</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="284"/>
+        <source>Formatting</source>
+        <translation>Formátování</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="230"/>
+        <source>Symbols</source>
+        <translation>Symboly</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="235"/>
+        <source>File</source>
+        <translation>Soubor</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="236"/>
+        <source>Edit</source>
+        <translation>Upravit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Help</source>
+        <translation>Nápověda</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="240"/>
+        <source>Open recent</source>
+        <translation>Otevřít nedávné</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="252"/>
+        <source>Export</source>
+        <translation>Exportovat</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Spell check</source>
+        <translation>Kontrola pravopisu</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="281"/>
+        <source>Default markup</source>
+        <translation>Výchozí syntax</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="321"/>
+        <source>Search</source>
+        <translation>Najít</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="323"/>
+        <source>Case sensitively</source>
+        <translation>Rozlišovat velikost písmen</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="458"/>
+        <source>New document</source>
+        <translation>Nový dokument</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="622"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Prosím, soubor někam uložte.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="738"/>
         <source>Select one or several files to open</source>
         <translation>Vyberte jeden nebo více souborů k otevření</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>Podporované soubory</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>Všechny soubory (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
+        <location filename="window.py" line="776"/>
         <source>Select file encoding from the list:</source>
         <translation>Vyberte ze seznamu kódování souboru:</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>Prostý text (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s soubory</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>Save file</source>
         <translation>Uložit soubor</translation>
     </message>
     <message>
-        <location filename="window.py" line="799"/>
+        <location filename="window.py" line="821"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Nelze uložit, protože soubor je pouze pro čtení!</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>Export document to ODT</source>
         <translation>Exportovat dokument do ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Textové soubory OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Soubory HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>Export document to PDF</source>
         <translation>Exportovat dokument do PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>PDF files (*.pdf)</source>
         <translation>Soubory PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="883"/>
+        <location filename="window.py" line="908"/>
         <source>Print document</source>
         <translation>Tisknout dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="904"/>
+        <location filename="window.py" line="932"/>
         <source>Export document</source>
         <translation>Exportovat dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="923"/>
+        <location filename="window.py" line="953"/>
         <source>Failed to execute the command:</source>
         <translation>Nepodařilo se spustit příkaz:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation>Alternativní text</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation>Odkaz</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1028"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation>Soubor byl smazán jinou aplikací.
+Před zavřením programu se ujistěte, že jste soubor uložili.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1035"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation>Soubor byl změněn. Chcete načíst novou verzi?
+(Tímto se zruší všechny změny)
+</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation>Pokud se rozhodnete soubor nenačíst, automatické ukádání bude vypnuto, aby se zabránilo ztrátě dat.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1064"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokument byl změněn. Chcete uložit své změny?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1055"/>
+        <location filename="window.py" line="1089"/>
         <source>HTML code</source>
         <translation>HTML kód</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (s použitím PyMarkups %s)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Jednoduchý, ale mocný editor pro Markdown a reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Website</source>
         <translation>Webové stránky</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Markdown syntax</source>
-        <translation>Syntax Markdownu</translation>
+        <translation>Syntax Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText syntaxe</translation>
     </message>
-    <message>
-        <location filename="window.py" line="1009"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="95"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="97"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="131"/>
-        <source>FakeVim mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="992"/>
-        <source>This file has been deleted by other application.
-Please make sure you save the file before exit.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1000"/>
-        <source>This document has been modified by other application.
-Do you want to reload the file (this will discard all your changes)?
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1005"/>
-        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="107"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>ReText %s (using PyMarkups %s)</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
