@@ -47,11 +47,6 @@
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Interface</source>
@@ -73,7 +68,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="102"/>
+        <location filename="config.py" line="103"/>
         <source>Help</source>
         <translation type="unfinished">Abi</translation>
     </message>
@@ -82,6 +77,16 @@
         <source>Use live preview by default</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -104,7 +109,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
@@ -122,15 +127,28 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ReTextEdit</name>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="115"/>
+        <location filename="tab.py" line="177"/>
         <source>New document</source>
         <translation>Uus dokument</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
@@ -138,420 +156,435 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
         <translation>Faili tööriistariba</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
         <translation>Muuda tööriistariba</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
         <translation>Otsingu tööriistariba</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>Uus</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>Ava</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>Salvesta</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Salvesta kui...</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Prindi</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>Printimise eelvaade</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>Vaata HTML koodi</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Leia tekst</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Eelvaade</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Aktiivne eelvaade</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
+        <location filename="window.py" line="149"/>
         <source>Fullscreen mode</source>
         <translation>Täisekraani režiim</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>Välju</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
         <translation>Võta tagasi</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>Korda</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>Kopeeri</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>Lõika</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>Aseta</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>Luba</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>Sea regioon</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
         <translation>Kasuta WebKit renderdajat</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="window.py" line="188"/>
         <source>Next</source>
         <translation>Järgmine</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="window.py" line="190"/>
         <source>Previous</source>
         <translation>Eelmine</translation>
     </message>
     <message>
-        <location filename="window.py" line="176"/>
+        <location filename="window.py" line="195"/>
         <source>Get help online</source>
         <translation>Saa abi internetist</translation>
     </message>
     <message>
-        <location filename="window.py" line="177"/>
+        <location filename="window.py" line="196"/>
         <source>About ReText</source>
         <translation>ReText kohta</translation>
     </message>
     <message>
-        <location filename="window.py" line="180"/>
+        <location filename="window.py" line="199"/>
         <source>About Qt</source>
         <translation>Qt kohta</translation>
     </message>
     <message>
-        <location filename="window.py" line="200"/>
+        <location filename="window.py" line="214"/>
         <source>Bold</source>
         <translation>Rasvane</translation>
     </message>
     <message>
-        <location filename="window.py" line="202"/>
+        <location filename="window.py" line="216"/>
         <source>Italic</source>
         <translation>Kaldu</translation>
     </message>
     <message>
-        <location filename="window.py" line="204"/>
+        <location filename="window.py" line="218"/>
         <source>Underline</source>
         <translation>Allajoonitud</translation>
     </message>
     <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>Sildid</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
+        <location filename="window.py" line="230"/>
         <source>Symbols</source>
         <translation>Sümbolid</translation>
     </message>
     <message>
-        <location filename="window.py" line="223"/>
+        <location filename="window.py" line="235"/>
         <source>File</source>
         <translation>Fail</translation>
     </message>
     <message>
-        <location filename="window.py" line="224"/>
+        <location filename="window.py" line="236"/>
         <source>Edit</source>
         <translation>Muuda</translation>
     </message>
     <message>
-        <location filename="window.py" line="225"/>
+        <location filename="window.py" line="237"/>
         <source>Help</source>
         <translation>Abi</translation>
     </message>
     <message>
-        <location filename="window.py" line="228"/>
+        <location filename="window.py" line="240"/>
         <source>Open recent</source>
         <translation>Ava hiljutine</translation>
     </message>
     <message>
-        <location filename="window.py" line="241"/>
+        <location filename="window.py" line="252"/>
         <source>Export</source>
         <translation>Ekspordi</translation>
     </message>
     <message>
-        <location filename="window.py" line="262"/>
+        <location filename="window.py" line="273"/>
         <source>Spell check</source>
         <translation>Õigekirjakontroll</translation>
     </message>
     <message>
-        <location filename="window.py" line="273"/>
+        <location filename="window.py" line="284"/>
         <source>Formatting</source>
         <translation>Vormindus</translation>
     </message>
     <message>
-        <location filename="window.py" line="313"/>
+        <location filename="window.py" line="321"/>
         <source>Search</source>
         <translation>Otsi</translation>
     </message>
     <message>
-        <location filename="window.py" line="315"/>
+        <location filename="window.py" line="323"/>
         <source>Case sensitively</source>
         <translation>Tõstutundeliselt</translation>
     </message>
     <message>
-        <location filename="window.py" line="442"/>
+        <location filename="window.py" line="458"/>
         <source>New document</source>
         <translation>Uus dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="591"/>
+        <location filename="window.py" line="622"/>
         <source>Please, save the file somewhere.</source>
         <translation>Palun salvesta fail kuhugi.</translation>
     </message>
     <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>Näita kataloogi</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Select one or several files to open</source>
         <translation>Vali avamiseks üks või mitu faili</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>Toetatud failid</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>Kõik failid (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>Tavaline tekst (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>Save file</source>
         <translation>Salvesta fail</translation>
     </message>
     <message>
-        <location filename="window.py" line="799"/>
+        <location filename="window.py" line="821"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Ei saa faili salvestada, kuna see fail on ainult lugemiseks!</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>Export document to ODT</source>
         <translation>Ekspordi dokument ODT formaati</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument tekstifailid (.*odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>HTML files (*.html *.htm)</source>
-        <translation>HTML failid (*.html, *.htm)</translation>
+        <translation>HTML failid (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>Export document to PDF</source>
         <translation>Ekspordi dokument PDF&apos;ina</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF failid (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="883"/>
+        <location filename="window.py" line="908"/>
         <source>Print document</source>
         <translation>Prindi dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="904"/>
+        <location filename="window.py" line="932"/>
         <source>Export document</source>
         <translation>Ekspordi dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="923"/>
+        <location filename="window.py" line="953"/>
         <source>Failed to execute the command:</source>
         <translation>Järgmise käsu täitmine ebaõnnestus:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="1064"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokumenti on muudetud.
 Soovid salvestada oma muudatused?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1055"/>
+        <location filename="window.py" line="1089"/>
         <source>HTML code</source>
         <translation>HTML kood</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Lihtne aga võimas Markdown ja reStructuredText redaktor</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Website</source>
         <translation>Veebileht</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Markdown syntax</source>
         <translation>Markdown süntaks</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText süntaks</translation>
     </message>
     <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s failid</translation>
     </message>
     <message>
-        <location filename="window.py" line="270"/>
+        <location filename="window.py" line="281"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="503"/>
+        <location filename="window.py" line="553"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="95"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
+        <location filename="window.py" line="776"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1009"/>
+        <location filename="window.py" line="1044"/>
         <source>Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="107"/>
         <source>Next tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="109"/>
         <source>Previous tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="144"/>
         <source>FakeVim mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="992"/>
+        <location filename="window.py" line="1028"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1000"/>
+        <location filename="window.py" line="1035"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="window.py" line="1040"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="window.py" line="117"/>
         <source>Change editor font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
+        <location filename="window.py" line="119"/>
         <source>Change preview font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
