@@ -5,82 +5,87 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>Comportamento</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Salva automaticamente documenti</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Open external links in ReText window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Editor</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Highlight current line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Show line numbers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Tab key inserts spaces</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Tabulation width</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Icon theme name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Markdown syntax extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="102"/>
-        <source>Help</source>
-        <translation type="unfinished">Aiuto</translation>
+        <translation>Ripristina dimensioni finestra</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilizza anteprima in tempo reale per impostazione predefinita</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Open external links in ReText window</source>
+        <translation>Apri collegamenti esterni nella finestra di ReText</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Estensioni alla sintassi Markdown (separate da virgole)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Abilita scorrimento sincronizzato per Markdown</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Editor</source>
+        <translation>Editor</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Highlight current line</source>
+        <translation>Evidenzia riga corrente</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Show line numbers</source>
+        <translation>Visualizza numeri di riga</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Tab key inserts spaces</source>
+        <translation>Il tasto Tab inserisce spazi</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Tabulation width</source>
+        <translation>Larghezza di tabulazione</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation>Traccia riga verticale alla colonna</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Interface</source>
+        <translation>Interfaccia</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Icon theme name</source>
+        <translation>Nome tema icone</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Stylesheet file</source>
+        <translation>File foglio di stile</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="103"/>
+        <source>Help</source>
+        <translation>Aiuto</translation>
     </message>
 </context>
 <context>
@@ -88,12 +93,12 @@
     <message>
         <location filename="config.py" line="34"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>(nessuno)</translation>
     </message>
     <message>
         <location filename="config.py" line="41"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona il file da aprire</translation>
     </message>
 </context>
 <context>
@@ -101,12 +106,12 @@
     <message>
         <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation type="unfinished"></translation>
+        <translation>Inserisci localizzazione (esempio: en_US)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
-        <translation type="unfinished"></translation>
+        <translation>Imposta come predefinito</translation>
     </message>
 </context>
 <context>
@@ -114,443 +119,474 @@
     <message>
         <location filename="fakevimeditor.py" line="64"/>
         <source>No write since last change (add ! to override)</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessuna scrittura dall&apos;ultima modifica (aggiungi ! per salvare comunque)</translation>
     </message>
     <message>
         <location filename="fakevimeditor.py" line="121"/>
         <source>Information</source>
-        <translation type="unfinished"></translation>
+        <translation>Informazione</translation>
+    </message>
+</context>
+<context>
+    <name>ReTextEdit</name>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation>Salva immagine</translation>
+    </message>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation>Immagini (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="115"/>
+        <location filename="tab.py" line="177"/>
         <source>New document</source>
         <translation>Nuovo documento</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossibile interpretare i contenuti del file, controlla che il &lt;a href=&quot;%s&quot;&gt;modulo richiesto&lt;/a&gt; sia installato!</translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
-        <translation>Toolbar File</translation>
+        <translation>Barra degli strumenti File</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
-        <translation>Toolbar Modifica</translation>
+        <translation>Barra degli strumenti Modifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
-        <translation>Toolbar Ricerca</translation>
+        <translation>Barra degli strumenti Ricerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>Nuovo</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>Apri</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="95"/>
+        <source>Set encoding</source>
+        <translation>Imposta codifica</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1044"/>
+        <source>Reload</source>
+        <translation>Ricarica</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>Salva</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Salva con nome</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="107"/>
+        <source>Next tab</source>
+        <translation>Scheda successiva</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Previous tab</source>
+        <translation>Scheda precedente</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Stampa</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
-        <translation>Stampa anteprima</translation>
+        <translation>Anteprima di stampa</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
-        <translation>Vedi codice HTML</translation>
+        <translation>Visualizza codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation>Modifica carattere editor</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation>Modifica carattere anteprima</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Trova testo</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Anteprima</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
-        <translation>Anteprima in diretta</translation>
+        <translation>Anteprima in tempo reale</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
+        <location filename="window.py" line="144"/>
+        <source>FakeVim mode</source>
+        <translation>Modalità di inserimento Vim</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
         <source>Fullscreen mode</source>
         <translation>Schermo intero</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="553"/>
+        <source>Preferences</source>
+        <translation>Preferenze</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>Esci</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>Ripristina</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>Taglia</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>Incolla</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>Attiva</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>Imposta localizzazione</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
         <translation>Usa il motore WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
-        <source>Next</source>
-        <translation>Avanti</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="174"/>
-        <source>Previous</source>
-        <translation>Indietro</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Get help online</source>
-        <translation>Ottieni aiuto online</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>About ReText</source>
-        <translation>A proposito di ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>About Qt</source>
-        <translation>A proposito di Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="200"/>
-        <source>Bold</source>
-        <translation>Grassetto</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="202"/>
-        <source>Italic</source>
-        <translation>Corsivo</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="204"/>
-        <source>Underline</source>
-        <translation>Sottolineato</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>Tag</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
-        <source>Symbols</source>
-        <translation>Simboli</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="223"/>
-        <source>File</source>
-        <translation>File</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="224"/>
-        <source>Edit</source>
-        <translation>Modifica</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Help</source>
-        <translation>Aiuto</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="228"/>
-        <source>Open recent</source>
-        <translation>Apri recente</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="241"/>
-        <source>Export</source>
-        <translation>Esporta</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="262"/>
-        <source>Spell check</source>
-        <translation>Correzione ortografica</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="273"/>
-        <source>Formatting</source>
-        <translation>Formattazione</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="313"/>
-        <source>Search</source>
-        <translation>Cerca</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="315"/>
-        <source>Case sensitively</source>
-        <translation>Distingui maiuscole/minuscole</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="442"/>
-        <source>New document</source>
-        <translation>Nuovo documento</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="591"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Per favore, salva il file da qualche parte.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>Mostra cartella</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
-        <source>Select one or several files to open</source>
-        <translation>Scegli uno o più file da aprire</translation>
+        <location filename="window.py" line="188"/>
+        <source>Next</source>
+        <translation>Avanti</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="190"/>
+        <source>Previous</source>
+        <translation>Indietro</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation>Chiudi</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="195"/>
+        <source>Get help online</source>
+        <translation>Ottieni aiuto online</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="196"/>
+        <source>About ReText</source>
+        <translation>Informazioni su ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="199"/>
+        <source>About Qt</source>
+        <translation>Informazioni su Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="214"/>
+        <source>Bold</source>
+        <translation>Grassetto</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Italic</source>
+        <translation>Corsivo</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="218"/>
+        <source>Underline</source>
+        <translation>Sottolineato</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="284"/>
+        <source>Formatting</source>
+        <translation>Formattazione</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="230"/>
+        <source>Symbols</source>
+        <translation>Simboli</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="235"/>
+        <source>File</source>
+        <translation>File</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="236"/>
+        <source>Edit</source>
+        <translation>Modifica</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Help</source>
+        <translation>Aiuto</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="240"/>
+        <source>Open recent</source>
+        <translation>Apri recente</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="252"/>
+        <source>Export</source>
+        <translation>Esporta</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Spell check</source>
+        <translation>Correttore ortografico</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="281"/>
+        <source>Default markup</source>
+        <translation>Linguaggio a marcatori predefinito</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="321"/>
+        <source>Search</source>
+        <translation>Cerca</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="323"/>
+        <source>Case sensitively</source>
+        <translation>Distingui maiuscole/minuscole</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="458"/>
+        <source>New document</source>
+        <translation>Nuovo documento</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="622"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Per favore, salva il file da qualche parte.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="738"/>
+        <source>Select one or several files to open</source>
+        <translation>Seleziona uno o più file da aprire</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>File supportati</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>Tutti i file (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="776"/>
+        <source>Select file encoding from the list:</source>
+        <translation>Seleziona la codifica del file dall&apos;elenco:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>Testo semplice (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
-        <source>Save file</source>
-        <translation>Salva file</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="799"/>
-        <source>Cannot save to file because it is read-only!</source>
-        <translation>Non posso salvare il file perché è read-only!</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="834"/>
-        <source>Export document to ODT</source>
-        <translation>Esporta documento in ODT</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="834"/>
-        <source>OpenDocument text files (*.odt)</source>
-        <translation>File di testo OpenDocumenti (*.odt)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="844"/>
-        <source>HTML files (*.html *.htm)</source>
-        <translation>file HTML (*.html *.htm)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="866"/>
-        <source>Export document to PDF</source>
-        <translation>Esporta documento su PDF</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="866"/>
-        <source>PDF files (*.pdf)</source>
-        <translation>File PDF (*.pdf)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="883"/>
-        <source>Print document</source>
-        <translation>Stampa documento</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="904"/>
-        <source>Export document</source>
-        <translation>Esporta documento</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="923"/>
-        <source>Failed to execute the command:</source>
-        <translation>Non sono riuscito ad eseguire il comando:</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1030"/>
-        <source>The document has been modified.
-Do you want to save your changes?</source>
-        <translation>Questo documento è stato modificato.
-Vuoi salvare le tue modifiche?</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1055"/>
-        <source>HTML code</source>
-        <translation>Codice HTML</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Editor Markdown e reStructuredText semplice e potente</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>Autore: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>Website</source>
-        <translation>Sito web</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>Markdown syntax</source>
-        <translation>Sintassi Markdown</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>reStructuredText syntax</source>
-        <translation>Sintassi reStructuredText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>File %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="270"/>
-        <source>Default markup</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="867"/>
+        <source>Save file</source>
+        <translation>Salva file</translation>
     </message>
     <message>
-        <location filename="window.py" line="503"/>
-        <source>Preferences</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="821"/>
+        <source>Cannot save to file because it is read-only!</source>
+        <translation>Impossibile salvare il file perché è in sola lettura!</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
-        <source>Set encoding</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="857"/>
+        <source>Export document to ODT</source>
+        <translation>Esporta documento nel formato ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
-        <source>Select file encoding from the list:</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="857"/>
+        <source>OpenDocument text files (*.odt)</source>
+        <translation>File di testo OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1009"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="867"/>
+        <source>HTML files (*.html *.htm)</source>
+        <translation>File HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="888"/>
+        <source>Export document to PDF</source>
+        <translation>Esporta documento nel formato PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="888"/>
+        <source>PDF files (*.pdf)</source>
+        <translation>File PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="908"/>
+        <source>Print document</source>
+        <translation>Stampa documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
-        <source>FakeVim mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="932"/>
+        <source>Export document</source>
+        <translation>Esporta documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="992"/>
+        <location filename="window.py" line="953"/>
+        <source>Failed to execute the command:</source>
+        <translation>Impossibile eseguire il comando:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation>Testo alternativo</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation>Testo collegamento</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1028"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
-        <translation type="unfinished"></translation>
+        <translation>Questo file è stato eliminato da un&apos;altra applicazione.
+Assicurati di salvare il file prima di uscire.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1000"/>
+        <location filename="window.py" line="1035"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Questo documento è stato modificato da un&apos;altra applicazione.
+Vuoi ricaricare il file (ciò comporterà la perdita di tutti i cambiamenti)?
+</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="window.py" line="1040"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation type="unfinished"></translation>
+        <translation>Se scegli di non ricaricare il file, la modalità salvataggio automatico sarà disabilitata per questa sessione per prevenire perdite di dati.</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="1064"/>
+        <source>The document has been modified.
+Do you want to save your changes?</source>
+        <translation>Il documento è stato modificato.
+Vuoi salvare le modifiche?</translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
+        <location filename="window.py" line="1089"/>
+        <source>HTML code</source>
+        <translation>Codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (utilizza PyMarkups %s)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>Simple but powerful editor for Markdown and reStructuredText</source>
+        <translation>Un editor semplice ma potente per Markdown e reStructuredText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>Autore: Dmitry Shachnev, 2011</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>Website</source>
+        <translation>Sito Web</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>Markdown syntax</source>
+        <translation>Sintassi Markdown</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
+        <source>reStructuredText syntax</source>
+        <translation>Sintassi reStructuredText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
