@@ -52,11 +52,6 @@
         <source>Tabulation width</source>
         <translation>Ширина табуляции</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation>Показывать разделитель в столбце</translation>
-    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Interface</source>
@@ -73,7 +68,7 @@
         <translation>Файл стиля Qt</translation>
     </message>
     <message>
-        <location filename="config.py" line="102"/>
+        <location filename="config.py" line="103"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
@@ -82,6 +77,16 @@
         <source>Use live preview by default</source>
         <translation>Включить живой просмотр по умолчанию</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Включить синхронную прокрутку для Markdown</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation>Рисовать вертикальную линию в столбце</translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -104,7 +109,7 @@
         <translation>Введите код локали (например: en_US)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Установить по умолчанию</translation>
     </message>
@@ -122,15 +127,28 @@
         <translation>Информация</translation>
     </message>
 </context>
+<context>
+    <name>ReTextEdit</name>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation>Сохранить изображение</translation>
+    </message>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation>Изображения (*.png *.jpg)</translation>
+    </message>
+</context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="115"/>
+        <location filename="tab.py" line="177"/>
         <source>New document</source>
         <translation>Новый документ</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Не удалось обработать содержимое файла, убедитесь, что установлен &lt;a href=&quot;%s&quot;&gt;необходимый модуль&lt;/a&gt;!</translation>
     </message>
@@ -138,370 +156,365 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
         <translation>Панель файла</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
         <translation>Панель редактирования</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
         <translation>Панель поиска</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>Новый</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>Открыть</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="95"/>
         <source>Set encoding</source>
         <translation>Установить кодировку</translation>
     </message>
     <message>
-        <location filename="window.py" line="1009"/>
+        <location filename="window.py" line="1044"/>
         <source>Reload</source>
         <translation>Загрузить заново</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Сохранить как</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="107"/>
         <source>Next tab</source>
         <translation>Следующая вкладка</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="109"/>
         <source>Previous tab</source>
         <translation>Предыдущая вкладка</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Распечатать</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>Предпросмотр печати</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>Просмотр кода HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="window.py" line="117"/>
         <source>Change editor font</source>
         <translation>Изменить шрифт редактора</translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
+        <location filename="window.py" line="119"/>
         <source>Change preview font</source>
         <translation>Изменить шрифт просмотра</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Поиск текста</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Просмотр</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Живой просмотр</translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
         <translation>Режим редактирования таблиц</translation>
     </message>
     <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="144"/>
         <source>FakeVim mode</source>
         <translation>Режим FakeVim</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
+        <location filename="window.py" line="149"/>
         <source>Fullscreen mode</source>
         <translation>Полноэкранный режим</translation>
     </message>
     <message>
-        <location filename="window.py" line="503"/>
+        <location filename="window.py" line="553"/>
         <source>Preferences</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>Выход</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
         <translation>Отменить действие</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>Повторить действие</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>Включить</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>Установить локаль</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
         <translation>Использовать движок WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>Открыть папку</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="window.py" line="188"/>
         <source>Next</source>
         <translation>Следующее</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="window.py" line="190"/>
         <source>Previous</source>
         <translation>Предыдущее</translation>
     </message>
     <message>
-        <location filename="window.py" line="176"/>
+        <location filename="window.py" line="195"/>
         <source>Get help online</source>
         <translation>Получить помощь в интернете</translation>
     </message>
     <message>
-        <location filename="window.py" line="177"/>
+        <location filename="window.py" line="196"/>
         <source>About ReText</source>
         <translation>О ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="180"/>
+        <location filename="window.py" line="199"/>
         <source>About Qt</source>
         <translation>О Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="200"/>
+        <location filename="window.py" line="214"/>
         <source>Bold</source>
         <translation>Полужирный</translation>
     </message>
     <message>
-        <location filename="window.py" line="202"/>
+        <location filename="window.py" line="216"/>
         <source>Italic</source>
         <translation>Курсив</translation>
     </message>
     <message>
-        <location filename="window.py" line="204"/>
+        <location filename="window.py" line="218"/>
         <source>Underline</source>
         <translation>Подчёркивание</translation>
     </message>
     <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>Теги</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
+        <location filename="window.py" line="230"/>
         <source>Symbols</source>
         <translation>Символы</translation>
     </message>
     <message>
-        <location filename="window.py" line="223"/>
+        <location filename="window.py" line="235"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="window.py" line="224"/>
+        <location filename="window.py" line="236"/>
         <source>Edit</source>
         <translation>Правка</translation>
     </message>
     <message>
-        <location filename="window.py" line="225"/>
+        <location filename="window.py" line="237"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
     <message>
-        <location filename="window.py" line="228"/>
+        <location filename="window.py" line="240"/>
         <source>Open recent</source>
         <translation>Открыть последние</translation>
     </message>
     <message>
-        <location filename="window.py" line="241"/>
+        <location filename="window.py" line="252"/>
         <source>Export</source>
         <translation>Экспорт</translation>
     </message>
     <message>
-        <location filename="window.py" line="262"/>
+        <location filename="window.py" line="273"/>
         <source>Spell check</source>
         <translation>Проверка орфографии</translation>
     </message>
     <message>
-        <location filename="window.py" line="270"/>
+        <location filename="window.py" line="281"/>
         <source>Default markup</source>
         <translation>Язык разметки по умолчанию</translation>
     </message>
     <message>
-        <location filename="window.py" line="273"/>
+        <location filename="window.py" line="284"/>
         <source>Formatting</source>
         <translation>Форматирование</translation>
     </message>
     <message>
-        <location filename="window.py" line="313"/>
+        <location filename="window.py" line="321"/>
         <source>Search</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location filename="window.py" line="315"/>
+        <location filename="window.py" line="323"/>
         <source>Case sensitively</source>
         <translation>Учитывать регистр</translation>
     </message>
     <message>
-        <location filename="window.py" line="442"/>
+        <location filename="window.py" line="458"/>
         <source>New document</source>
         <translation>Новый документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="591"/>
+        <location filename="window.py" line="622"/>
         <source>Please, save the file somewhere.</source>
         <translation>Сначала сохраните файл.</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Select one or several files to open</source>
         <translation>Выберите один или несколько файлов для открытия</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>Поддерживаемые файлы</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>Все файлы (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
+        <location filename="window.py" line="776"/>
         <source>Select file encoding from the list:</source>
         <translation>Выберите кодировку файла из списка:</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>Простой текст (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Файлы %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
     <message>
-        <location filename="window.py" line="799"/>
+        <location filename="window.py" line="821"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Невозможно сохранить в файл, так как он доступен только для чтения!</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>Export document to ODT</source>
         <translation>Экспортировать документ как ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Файлы текста OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Файлы HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>Export document to PDF</source>
         <translation>Экспортировать документ как PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>PDF files (*.pdf)</source>
         <translation>Файлы PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="883"/>
+        <location filename="window.py" line="908"/>
         <source>Print document</source>
         <translation>Распечатать документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="904"/>
+        <location filename="window.py" line="932"/>
         <source>Export document</source>
         <translation>Экспортировать документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="923"/>
+        <location filename="window.py" line="953"/>
         <source>Failed to execute the command:</source>
         <translation>Невозможно запустить команду:</translation>
     </message>
     <message>
-        <location filename="window.py" line="992"/>
+        <location filename="window.py" line="1028"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Этот файл был удалён другим приложением.
 Пожалуйста, убедитесь перед выходом, что вы сохранили файл.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1000"/>
+        <location filename="window.py" line="1035"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -510,51 +523,71 @@ Do you want to reload the file (this will discard all your changes)?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="window.py" line="1040"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Если вы решите не перезагружать файл, режим автоматического сохранения будет отключён для этого сеанса в целях предотвращения потери данных.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="1064"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ был изменён.
 Сохранить изменения?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1055"/>
+        <location filename="window.py" line="1089"/>
         <source>HTML code</source>
         <translation>код HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s (использует PyMarkups %s)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Простой, но мощный редактор для Markdown и reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Автор: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Website</source>
         <translation>Веб-сайт</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Markdown syntax</source>
         <translation>Синтаксис Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>reStructuredText syntax</source>
         <translation>Синтаксис reStructuredText</translation>
     </message>
+    <message>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation>Закрыть</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation>Альтернативный текст</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation>Текст ссылки</translation>
+    </message>
 </context>
 </TS>
