@@ -5,82 +5,87 @@
     <message>
         <location filename="config.py" line="67"/>
         <source>Behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>Режим</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Automatically save documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Автоматично зберігати документи</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Restore window geometry</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Open external links in ReText window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Editor</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Highlight current line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Show line numbers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Tab key inserts spaces</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Tabulation width</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Icon theme name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Markdown syntax extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="config.py" line="102"/>
-        <source>Help</source>
-        <translation type="unfinished">Довідка</translation>
+        <translation>Відновлювати геометрію вікна</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
+        <translation>Використовувати живий перегляд типово</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Open external links in ReText window</source>
+        <translation>Відкриті зовнішні посилання у вікні ReText</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Розширення синтаксису Markdown (розділені комами)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Увімкнути синхронне гортання для Markdown</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Editor</source>
+        <translation>Редагувати</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Highlight current line</source>
+        <translation>Виділяти поточний рядок</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Show line numbers</source>
+        <translation>Показувати номери рядків</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Tab key inserts spaces</source>
+        <translation>Поставити пробіл клявішею Tab</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Tabulation width</source>
+        <translation>Ширина табулювання</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Draw vertical line at column</source>
+        <translation>Малювати вертикальну лінію у стовпчику</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Interface</source>
+        <translation>Інтерфейс</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Icon theme name</source>
+        <translation>Встановити тему піктограм</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Stylesheet file</source>
+        <translation>Файл стилю Qt</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="103"/>
+        <source>Help</source>
+        <translation>Довідка</translation>
     </message>
 </context>
 <context>
@@ -88,12 +93,12 @@
     <message>
         <location filename="config.py" line="34"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>(не обраний)</translation>
     </message>
     <message>
         <location filename="config.py" line="41"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Виберіть файл для відкриття</translation>
     </message>
 </context>
 <context>
@@ -101,12 +106,12 @@
     <message>
         <location filename="dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation type="unfinished"></translation>
+        <translation>Введіть код мови (наприклад: uk_UA)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
-        <translation type="unfinished"></translation>
+        <translation>Типово</translation>
     </message>
 </context>
 <context>
@@ -114,444 +119,475 @@
     <message>
         <location filename="fakevimeditor.py" line="64"/>
         <source>No write since last change (add ! to override)</source>
-        <translation type="unfinished"></translation>
+        <translation>Є незбережені зміни (додайте ! для нехтування)</translation>
     </message>
     <message>
         <location filename="fakevimeditor.py" line="121"/>
         <source>Information</source>
-        <translation type="unfinished"></translation>
+        <translation>Інформація</translation>
+    </message>
+</context>
+<context>
+    <name>ReTextEdit</name>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation>Зберегти зображення</translation>
+    </message>
+    <message>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation>Зображення (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="115"/>
+        <location filename="tab.py" line="177"/>
         <source>New document</source>
         <translation>Новий документ</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>Неможливо розпізнати вміст фалу, перевірте наявність &lt;a href=&quot;%s&quot;&gt;необхідних модулів&lt;/a&gt;!</translation>
+        <translation>Не вдалося опрацювати вміст файлу, переконайтеся, що встановлено &lt;a href=&quot;%s&quot;&gt;необхідний модуль&lt;/a&gt;!</translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
         <translation>Панель файлу</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
         <translation>Панель редагування</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
         <translation>Панель пошуку</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>Новий</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>Відкрити</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="95"/>
+        <source>Set encoding</source>
+        <translation>Встановити кодування</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1044"/>
+        <source>Reload</source>
+        <translation>Завантажити заново</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>Зберегти</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>Зберегти як</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="107"/>
+        <source>Next tab</source>
+        <translation>Наступна вкладка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="109"/>
+        <source>Previous tab</source>
+        <translation>Попередня вкладка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>Друкувати</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>Попередній перегляд перед друком</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>Переглянути код HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="117"/>
+        <source>Change editor font</source>
+        <translation>Змінити шрифт редактора</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="119"/>
+        <source>Change preview font</source>
+        <translation>Змінити шрифт перегляду</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>Знайти текст</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>Перегляд</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>Одночасний перегляд</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
-        <source>Fullscreen mode</source>
-        <translation>На весь екран</translation>
+        <location filename="window.py" line="144"/>
+        <source>FakeVim mode</source>
+        <translation>Режим FakeVim</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="149"/>
+        <source>Fullscreen mode</source>
+        <translation>На увесь екран</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="553"/>
+        <source>Preferences</source>
+        <translation>Вибране</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>Вийти</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
-        <translation>Відмінити дію</translation>
+        <translation>Скасувати дію</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>Повторити дію</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>Скопіювати</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>Вирізати</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>Вставити</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>Увімкнути</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>Вибрати мову</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
         <translation>Використовувати WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
-        <source>Next</source>
-        <translation>Наступне</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="174"/>
-        <source>Previous</source>
-        <translation>Попереднє</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="176"/>
-        <source>Get help online</source>
-        <translation>Отримати довідку в мережі</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="177"/>
-        <source>About ReText</source>
-        <translation>Про ReText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="180"/>
-        <source>About Qt</source>
-        <translation>Про Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="200"/>
-        <source>Bold</source>
-        <translation>Потовщення</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="202"/>
-        <source>Italic</source>
-        <translation>Нахил</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="204"/>
-        <source>Underline</source>
-        <translation>Підкреслення</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>Теги</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
-        <source>Symbols</source>
-        <translation>Символи</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="223"/>
-        <source>File</source>
-        <translation>Файл</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="224"/>
-        <source>Edit</source>
-        <translation>Редагування</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Help</source>
-        <translation>Довідка</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="228"/>
-        <source>Open recent</source>
-        <translation>Відкрити останній</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="241"/>
-        <source>Export</source>
-        <translation>Експорт</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="262"/>
-        <source>Spell check</source>
-        <translation>Перевірка правопису</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="273"/>
-        <source>Formatting</source>
-        <translation>Форматування</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="313"/>
-        <source>Search</source>
-        <translation>Пошук</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="315"/>
-        <source>Case sensitively</source>
-        <translation>Врахувати регістр</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="442"/>
-        <source>New document</source>
-        <translation>Новий документ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="591"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Будь ласка, збережіть кудись файл.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>Переглянути теку</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="188"/>
+        <source>Next</source>
+        <translation>Наступне</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="190"/>
+        <source>Previous</source>
+        <translation>Попереднє</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation>Закрити</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="195"/>
+        <source>Get help online</source>
+        <translation>Отримати довідку в мережі</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="196"/>
+        <source>About ReText</source>
+        <translation>Про ReText</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="199"/>
+        <source>About Qt</source>
+        <translation>Про Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="214"/>
+        <source>Bold</source>
+        <translation>Потовщення</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="216"/>
+        <source>Italic</source>
+        <translation>Нахил</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="218"/>
+        <source>Underline</source>
+        <translation>Підкреслення</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="284"/>
+        <source>Formatting</source>
+        <translation>Форматування</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="230"/>
+        <source>Symbols</source>
+        <translation>Символи</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="235"/>
+        <source>File</source>
+        <translation>Файл</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="236"/>
+        <source>Edit</source>
+        <translation>Редагування</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Help</source>
+        <translation>Довідка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="240"/>
+        <source>Open recent</source>
+        <translation>Відкрити останній</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="252"/>
+        <source>Export</source>
+        <translation>Експорт</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Spell check</source>
+        <translation>Перевірка правопису</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="281"/>
+        <source>Default markup</source>
+        <translation>Типова розмітка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="321"/>
+        <source>Search</source>
+        <translation>Пошук</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="323"/>
+        <source>Case sensitively</source>
+        <translation>Врахувати регістр</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="458"/>
+        <source>New document</source>
+        <translation>Новий документ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="622"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Будь ласка, збережіть кудись файл.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="738"/>
         <source>Select one or several files to open</source>
         <translation>Виберіть один або кілька файлів</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>Файли що підтримуються</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>Всі файли (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="776"/>
+        <source>Select file encoding from the list:</source>
+        <translation>Виберіть методу кодування із переліку:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>Простий текст (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Файли %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>Save file</source>
         <translation>Зберегти файл</translation>
     </message>
     <message>
-        <location filename="window.py" line="799"/>
+        <location filename="window.py" line="821"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Неможливо зберегти, файл тільки для читання!</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>Export document to ODT</source>
         <translation>Експортувати як ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Текстові файли OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Файли HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>Export document to PDF</source>
         <translation>Експортувати як PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>PDF files (*.pdf)</source>
         <translation>Файли PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="883"/>
+        <location filename="window.py" line="908"/>
         <source>Print document</source>
         <translation>Друкувати документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="904"/>
+        <location filename="window.py" line="932"/>
         <source>Export document</source>
         <translation>Експортувати документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="923"/>
+        <location filename="window.py" line="953"/>
         <source>Failed to execute the command:</source>
         <translation>Помилка при виконанні команди:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation>Альтернативний текст</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation>Текст посилання</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1028"/>
+        <source>This file has been deleted by other application.
+Please make sure you save the file before exit.</source>
+        <translation>Цей файл був вилучений іншим користувачем.
+Будь ласка, переконайтеся перед виходом, що Ви зберегли файл.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1035"/>
+        <source>This document has been modified by other application.
+Do you want to reload the file (this will discard all your changes)?
+</source>
+        <translation>Цей документ був змінений іншим застосунком.
+Чи волієте Ви завантажити файл поновій (це скасує усі Ваші зміни)?
+</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1040"/>
+        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
+        <translation>Якщо Ви вирішите не перезавантажувати файл, режим автоматичного збереження буде вимкнено для цього сеансу з метою попередження втрати даних.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1064"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ було змінено.
 Бажаєте зберегти ці зміни?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1055"/>
+        <location filename="window.py" line="1089"/>
         <source>HTML code</source>
         <translation>Код HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (використовує PyMarkups %s)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1100"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Простий але потужний текстовий редактор для Markdown та reStructuredText
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Автор: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Website</source>
         <translation>Веб-сайт</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Markdown syntax</source>
         <translation>Синтаксис Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>reStructuredText syntax</source>
         <translation>Синтаксис reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="270"/>
-        <source>Default markup</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="503"/>
-        <source>Preferences</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="83"/>
-        <source>Set encoding</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="750"/>
-        <source>Select file encoding from the list:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1009"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="95"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="97"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="131"/>
-        <source>FakeVim mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="992"/>
-        <source>This file has been deleted by other application.
-Please make sure you save the file before exit.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1000"/>
-        <source>This document has been modified by other application.
-Do you want to reload the file (this will discard all your changes)?
-</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1005"/>
-        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="105"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="107"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1066"/>
-        <source>ReText %s (using PyMarkups %s)</source>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
