@@ -17,6 +17,11 @@
         <source>Restore window geometry</source>
         <translation>恢复窗口位置大小</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Use live preview by default</source>
+        <translation>默认使用实时预览</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Open external links in ReText window</source>
@@ -27,6 +32,11 @@
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Markdown 语法扩展 (逗号分隔)</translation>
     </message>
+    <message>
+        <location filename="config.py" line="67"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>对Markdown开启编辑与预览的同步滚动</translation>
+    </message>
     <message>
         <location filename="config.py" line="67"/>
         <source>Editor</source>
@@ -54,8 +64,8 @@
     </message>
     <message>
         <location filename="config.py" line="67"/>
-        <source>Display right margin at column</source>
-        <translation>显示右列页边距</translation>
+        <source>Draw vertical line at column</source>
+        <translation>画出垂直边界线</translation>
     </message>
     <message>
         <location filename="config.py" line="67"/>
@@ -73,15 +83,10 @@
         <translation>样式表文件</translation>
     </message>
     <message>
-        <location filename="config.py" line="102"/>
+        <location filename="config.py" line="103"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
-    <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
@@ -104,7 +109,7 @@
         <translation>输入语言名称 (例如: zh_CN)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="49"/>
+        <location filename="dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>设为默认</translation>
     </message>
@@ -123,385 +128,408 @@
     </message>
 </context>
 <context>
-    <name>ReTextTab</name>
+    <name>ReTextEdit</name>
     <message>
-        <location filename="tab.py" line="115"/>
-        <source>New document</source>
-        <translation>新文件</translation>
+        <location filename="editor.py" line="285"/>
+        <source>Save image</source>
+        <translation>保存图片</translation>
     </message>
     <message>
-        <location filename="tab.py" line="121"/>
+        <location filename="editor.py" line="285"/>
+        <source>Images (*.png *.jpg)</source>
+        <translation>图片 (*.png *.jpg)</translation>
+    </message>
+</context>
+<context>
+    <name>ReTextTab</name>
+    <message>
+        <location filename="tab.py" line="177"/>
+        <source>New document</source>
+        <translation>新建文档</translation>
+    </message>
+    <message>
+        <location filename="tab.py" line="182"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>不能处理文件内容，检查你是否安装了 &lt;a href=&quot;%s&quot;&gt;必需的模块&lt;/a&gt;！</translation>
+        <translation>不能粘贴文件内容，检查下是否安装了 &lt;a href=&quot;%s&quot;&gt;必要模块&lt;/a&gt; ！</translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="69"/>
+        <location filename="window.py" line="81"/>
         <source>File toolbar</source>
         <translation>文件工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="71"/>
+        <location filename="window.py" line="83"/>
         <source>Edit toolbar</source>
         <translation>编辑工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="73"/>
+        <location filename="window.py" line="85"/>
         <source>Search toolbar</source>
         <translation>搜索工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="77"/>
+        <location filename="window.py" line="89"/>
         <source>New</source>
         <translation>新建</translation>
     </message>
     <message>
-        <location filename="window.py" line="80"/>
+        <location filename="window.py" line="92"/>
         <source>Open</source>
         <translation>打开</translation>
     </message>
     <message>
-        <location filename="window.py" line="83"/>
+        <location filename="window.py" line="95"/>
         <source>Set encoding</source>
         <translation>设置编码方式</translation>
     </message>
     <message>
-        <location filename="window.py" line="1009"/>
+        <location filename="window.py" line="1044"/>
         <source>Reload</source>
         <translation>重载</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="window.py" line="101"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="window.py" line="105"/>
         <source>Save as</source>
         <translation>另存为</translation>
     </message>
     <message>
-        <location filename="window.py" line="95"/>
+        <location filename="window.py" line="107"/>
         <source>Next tab</source>
         <translation>下一个标签</translation>
     </message>
     <message>
-        <location filename="window.py" line="97"/>
+        <location filename="window.py" line="109"/>
         <source>Previous tab</source>
         <translation>上一个标签</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="window.py" line="111"/>
         <source>Print</source>
         <translation>打印</translation>
     </message>
     <message>
-        <location filename="window.py" line="102"/>
+        <location filename="window.py" line="114"/>
         <source>Print preview</source>
         <translation>打印预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="104"/>
+        <location filename="window.py" line="116"/>
         <source>View HTML code</source>
         <translation>查看 HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="window.py" line="117"/>
         <source>Change editor font</source>
         <translation>修改编辑器字体</translation>
     </message>
     <message>
-        <location filename="window.py" line="107"/>
+        <location filename="window.py" line="119"/>
         <source>Change preview font</source>
         <translation>修改预览字体</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="121"/>
         <source>Find text</source>
         <translation>查找文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="125"/>
         <source>Preview</source>
         <translation>预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="window.py" line="135"/>
         <source>Live preview</source>
         <translation>实时预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="128"/>
-        <source>Table mode</source>
-        <translation>表格样式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="131"/>
+        <location filename="window.py" line="144"/>
         <source>FakeVim mode</source>
         <translation>FakeVim 模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="136"/>
+        <location filename="window.py" line="149"/>
         <source>Fullscreen mode</source>
         <translation>全屏模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="503"/>
+        <location filename="window.py" line="553"/>
         <source>Preferences</source>
         <translation>个人偏好</translation>
     </message>
     <message>
-        <location filename="window.py" line="146"/>
+        <location filename="window.py" line="159"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="window.py" line="149"/>
+        <location filename="window.py" line="162"/>
         <source>Undo</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="window.py" line="151"/>
+        <location filename="window.py" line="164"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="window.py" line="166"/>
         <source>Copy</source>
         <translation>复制</translation>
     </message>
     <message>
-        <location filename="window.py" line="155"/>
+        <location filename="window.py" line="168"/>
         <source>Cut</source>
         <translation>剪切</translation>
     </message>
     <message>
-        <location filename="window.py" line="157"/>
+        <location filename="window.py" line="170"/>
         <source>Paste</source>
         <translation>粘贴</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="180"/>
         <source>Enable</source>
         <translation>激活</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="181"/>
         <source>Set locale</source>
         <translation>选择界面语言</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="182"/>
         <source>Use WebKit renderer</source>
         <translation>使用 WebKit 渲染</translation>
     </message>
     <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="187"/>
         <source>Show directory</source>
         <translation>显示文件夹</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="window.py" line="188"/>
         <source>Next</source>
         <translation>下一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="window.py" line="190"/>
         <source>Previous</source>
         <translation>上一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="176"/>
+        <location filename="window.py" line="192"/>
+        <source>Close</source>
+        <translation>关闭</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="195"/>
         <source>Get help online</source>
         <translation>在线获取帮助（英文）</translation>
     </message>
     <message>
-        <location filename="window.py" line="177"/>
+        <location filename="window.py" line="196"/>
         <source>About ReText</source>
         <translation>关于 ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="180"/>
+        <location filename="window.py" line="199"/>
         <source>About Qt</source>
         <translation>关于 Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="200"/>
+        <location filename="window.py" line="214"/>
         <source>Bold</source>
         <translation>加粗</translation>
     </message>
     <message>
-        <location filename="window.py" line="202"/>
+        <location filename="window.py" line="216"/>
         <source>Italic</source>
         <translation>倾斜</translation>
     </message>
     <message>
-        <location filename="window.py" line="204"/>
+        <location filename="window.py" line="218"/>
         <source>Underline</source>
         <translation>下划线</translation>
     </message>
     <message>
-        <location filename="window.py" line="212"/>
-        <source>Tags</source>
-        <translation>标签</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="216"/>
-        <source>Symbols</source>
-        <translation>符号</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="223"/>
-        <source>File</source>
-        <translation>文件</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="224"/>
-        <source>Edit</source>
-        <translation>编辑</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="225"/>
-        <source>Help</source>
-        <translation>帮助</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="228"/>
-        <source>Open recent</source>
-        <translation>打开最近使用</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="241"/>
-        <source>Export</source>
-        <translation>导出</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="262"/>
-        <source>Spell check</source>
-        <translation>拼写检查</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="270"/>
-        <source>Default markup</source>
-        <translation>默认编辑模式</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="273"/>
+        <location filename="window.py" line="284"/>
         <source>Formatting</source>
         <translation>字符样式</translation>
     </message>
     <message>
-        <location filename="window.py" line="313"/>
+        <location filename="window.py" line="230"/>
+        <source>Symbols</source>
+        <translation>符号</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="235"/>
+        <source>File</source>
+        <translation>文件</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="236"/>
+        <source>Edit</source>
+        <translation>编辑</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="237"/>
+        <source>Help</source>
+        <translation>帮助</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="240"/>
+        <source>Open recent</source>
+        <translation>打开最近使用</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="252"/>
+        <source>Export</source>
+        <translation>导出</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="273"/>
+        <source>Spell check</source>
+        <translation>拼写检查</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="281"/>
+        <source>Default markup</source>
+        <translation>默认编辑模式</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="321"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
     <message>
-        <location filename="window.py" line="315"/>
+        <location filename="window.py" line="323"/>
         <source>Case sensitively</source>
         <translation>对大小写敏感</translation>
     </message>
     <message>
-        <location filename="window.py" line="442"/>
+        <location filename="window.py" line="458"/>
         <source>New document</source>
         <translation>新文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="591"/>
+        <location filename="window.py" line="622"/>
         <source>Please, save the file somewhere.</source>
         <translation>请，保存到别的地方呦！</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Select one or several files to open</source>
         <translation>选择一个或多个文件打开</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>Supported files</source>
         <translation>支持的文件类型</translation>
     </message>
     <message>
-        <location filename="window.py" line="711"/>
+        <location filename="window.py" line="738"/>
         <source>All files (*)</source>
         <translation>全部文件 (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
+        <location filename="window.py" line="776"/>
         <source>Select file encoding from the list:</source>
         <translation>从列表中选择文件编码方式</translation>
     </message>
     <message>
-        <location filename="window.py" line="770"/>
+        <location filename="window.py" line="797"/>
         <source>Plain text (*.txt)</source>
         <translation>普通文本文档 (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="773"/>
+        <location filename="window.py" line="800"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s 文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>Save file</source>
         <translation>保存文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="799"/>
+        <location filename="window.py" line="821"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>不能保存文件因为当前文件或文件夹只读！</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>Export document to ODT</source>
         <translation>导出文件到 ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="834"/>
+        <location filename="window.py" line="857"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument 文本文件 (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="844"/>
+        <location filename="window.py" line="867"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 文件 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>Export document to PDF</source>
         <translation>导出文件到 PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="866"/>
+        <location filename="window.py" line="888"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 文件 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="883"/>
+        <location filename="window.py" line="908"/>
         <source>Print document</source>
         <translation>打印文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="904"/>
+        <location filename="window.py" line="932"/>
         <source>Export document</source>
         <translation>导出文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="923"/>
+        <location filename="window.py" line="953"/>
         <source>Failed to execute the command:</source>
         <translation>不能执行命令:</translation>
     </message>
     <message>
-        <location filename="window.py" line="992"/>
+        <location filename="window.py" line="987"/>
+        <source>Alt text</source>
+        <translation>替换文本</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="988"/>
+        <source>Link text</source>
+        <translation>链接文本</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1028"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>此文件已被其他应用程序删除。
 请确保在退出程序前保存了文件。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1000"/>
+        <location filename="window.py" line="1035"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -510,50 +538,55 @@ Do you want to reload the file (this will discard all your changes)?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="window.py" line="1040"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>如果不重新载入文件，将禁用该会话的自动保存模式，以防止数据丢失。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1030"/>
+        <location filename="window.py" line="1064"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>文件已更改，确认保存吗？</translation>
     </message>
     <message>
-        <location filename="window.py" line="1055"/>
+        <location filename="window.py" line="1089"/>
         <source>HTML code</source>
         <translation>HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s（使用 PyMarkups %s）</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>简单高效的 Markdown 与 ReStructuredText 编辑器</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Website</source>
         <translation>网站</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>Markdown syntax</source>
         <translation>Markdown 语法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1066"/>
+        <location filename="window.py" line="1100"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText 语法</translation>
     </message>
+    <message>
+        <location filename="window.py" line="140"/>
+        <source>Table editing mode</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
