@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+# vim: ts=8:sts=8:sw=8:noexpandtab
 
 # ReText
 # Copyright 2011-2015 Dmitry Shachnev
@@ -16,10 +17,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import multiprocessing as mp
 import sys
 import signal
+import markups
+from os import devnull
 from os.path import join
-from ReText import datadirs, globalSettings, app_version
+from ReText import datadirs, settings, globalSettings, app_version
 from ReText.window import ReTextWindow
 
 from PyQt5.QtCore import QFile, QFileInfo, QIODevice, QLibraryInfo, \
@@ -28,11 +32,20 @@ from PyQt5.QtWidgets import QApplication
 from PyQt5.QtNetwork import QNetworkProxyFactory
 
 def canonicalize(option):
-	if option == '--preview':
+	if option in ('--preview', '-'):
 		return option
 	return QFileInfo(option).canonicalFilePath()
 
 def main():
+	if markups.__version_tuple__ < (2, ):
+		sys.exit('Error: ReText needs PyMarkups 2.0 or newer to run.')
+
+	# If we're running on Windows without a console, then discard stdout
+	# and save stderr to a file to facilitate debugging in case of crashes.
+	if sys.executable.endswith('pythonw.exe'):
+		sys.stdout = open(devnull, 'w')
+		sys.stderr = open('stderr.log', 'w')
+
 	app = QApplication(sys.argv)
 	app.setOrganizationName("ReText project")
 	app.setApplicationName("ReText")
@@ -48,10 +61,11 @@ def main():
 		                     join(path, 'locale')):
 			break
 	QtTranslator = QTranslator()
-	QtTranslator.load("qt_" + globalSettings.uiLanguage,
+	QtTranslator.load("qtbase_" + globalSettings.uiLanguage,
 		QLibraryInfo.location(QLibraryInfo.TranslationsPath))
 	app.installTranslator(RtTranslator)
 	app.installTranslator(QtTranslator)
+	print('Using configuration file:', settings.fileName())
 	if globalSettings.appStyleSheet:
 		sheetfile = QFile(globalSettings.appStyleSheet)
 		sheetfile.open(QIODevice.ReadOnly)
@@ -63,6 +77,7 @@ def main():
 	# need to have a list of canonical names before loading
 	fileNames = list(map(canonicalize, sys.argv[1:]))
 	previewMode = False
+	readStdIn = False
 	for fileName in fileNames:
 		if QFile.exists(fileName):
 			window.openFileWrapper(fileName)
@@ -71,11 +86,17 @@ def main():
 				window.preview(True)
 		elif fileName == '--preview':
 			previewMode = True
-	inputData = '' if sys.stdin.isatty() else sys.stdin.read()
+		elif fileName == '-':
+			readStdIn = True
+
+	inputData = ''
+	if readStdIn and sys.stdin is not None:
+		inputData = sys.stdin.read()
 	if inputData or not window.tabWidget.count():
 		window.createNew(inputData)
 	signal.signal(signal.SIGINT, lambda sig, frame: window.close())
 	sys.exit(app.exec())
 
 if __name__ == '__main__':
+	mp.set_start_method('spawn')
 	main()
